@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+import pkg_resources
 
-VERSION = (0, 1, 3)
+pkg_resources.declare_namespace(__name__)
+
+VERSION = (0, 1, 4)
 
 __version__ = ".".join(map(str, VERSION))
 __status__ = "Development"
